@@ -1,12 +1,10 @@
 import os
 
-import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import progressbar
 import seaborn as sns
-from mpl_toolkits.axes_grid.anchored_artists import AnchoredText
 
 
 class Eda:
@@ -163,7 +161,6 @@ class Eda:
         s = s.sort_values(ascending=False)
         s_df = s.reset_index()
         s_df.columns = ["feature_1", "feature_2", "corr"]
-        print(s_df.head(20))
         return s_df
 
     def check_unique_by_identifier_col(self, df, identifier_col):
@@ -180,12 +177,12 @@ class Eda:
 
         """
 
-        dup_rows = pd.concat(
-            x for col, x in df.groupby(identifier_col) if len(x) > 1
-        ).sort_values(identifier_col)
-
-        print("Duplicate identifier columns:")
-        print(dup_rows)
+        try:
+            dup_rows = pd.concat(
+                x for col, x in df.groupby(identifier_col) if len(x) > 1
+            ).sort_values(identifier_col)
+        except Exception:
+            return "No duplicate rows found."
 
         return dup_rows
 
@@ -213,7 +210,7 @@ class Eda:
             ax.set_title(col)
 
             sns.violinplot(
-                x=df[col], orient="v", ax=ax,
+                x=df[col], ax=ax,
             )
 
             text = "75th Percentile: {}\nMedian: {}\n25th Percentile: {}".format(
@@ -221,8 +218,18 @@ class Eda:
                 round(np.median(df[col]), 2),
                 round(np.percentile(df[col], 25), 2),
             )
-            at = AnchoredText(text, prop=dict(size=15), frameon=True, loc=1)
-            ax.add_artist(at)
+
+            # Place a text box in upper left in axes coords
+            props = dict(boxstyle="round", facecolor="white", alpha=0.5)
+            ax.text(
+                0.05,
+                0.95,
+                text,
+                transform=ax.transAxes,
+                fontsize=14,
+                verticalalignment="top",
+                bbox=props,
+            )
             plt.tight_layout()
 
             plt.savefig("../images/violinplot_{}.png".format(col))
